Module coding

Module coding 

Encoding of values of any type to/from a sequence of code words of fixed bit length.

Re-exports

pub use minimum_redundancy;

Structs

BuildGeometricUnlimited
BuildMinimumRedundancy
FragmentsIterator
Iterator over codeword fragments.
GeometricUnlimited
GeometricUnlimitedDecoder
U8Code

Enums

DecodingResult
Result of fragment decoding returned be consume method of Decoder.

Traits

BuildCoding
Coding builder.
Coding
A bijection between values and codewords. Codewords are sequences of fragments. Each fragment occupies constant number of bits.
Decoder
Decoder that decodes a value for codeword given fragment by fragment.
SerializableCoding
Codings that implement SerializableCoding can be serialized/deserialized.