Module csf::ls

source ·
Compressed static maps based on solving linear systems.

Modules

Structs

  • Compressed static function (immutable map) that maps hashable keys to values of any type.
  • Pre-fills the value vector of ls::Map with random values.
  • Pre-fills each 64-bit fragment of the value vector of ls::Map with given pattern.
  • Static function (immutable map) that maps hashable keys to unsigned integer values of given bit-size.
  • Configuration accepted by ls::Map constructors.

Traits