EdgeValues

Trait EdgeValues 

pub trait EdgeValues {
    type Value;

    // Required methods
    fn add_or_remove_value(
        &mut self,
        a: usize,
        b: usize,
        c: usize,
        value: Self::Value,
    );
    fn get_value(&self, vertex: usize) -> Self::Value;
}
The holders of this trait store the values assigned to the edges of the HyperGraph.

Required Associated Types

type Value

Type of stored values.

Required Methods

fn add_or_remove_value( &mut self, a: usize, b: usize, c: usize, value: Self::Value, )

Add or remove given value to/from the list of values assigned to all the given vertices.

fn get_value(&self, vertex: usize) -> Self::Value

Returns value assigned to the given vertex. It can only be called when exactly one value is assigned to the edge.

Implementations on Foreign Types

Source

impl EdgeValues for ()

Does not store any values.

Source

type Value = ()

Source

fn add_or_remove_value( &mut self, _a: usize, _b: usize, _c: usize, _value: Self::Value, )

Source

fn get_value(&self, _vertex: usize) -> Self::Value

Implementors