Encoding of values of any type to/from a sequence of code words of fixed bit length.
Re-exports
pub use minimum_redundancy;
Structs
- Build
Geometric Unlimited - Build
Minimum Redundancy - Fragments
Iterator - Iterator over codeword fragments.
- Geometric
Unlimited - Geometric
Unlimited Decoder - U8Code
Enums
- Decoding
Result - Result of fragment decoding returned be
consumemethod ofDecoder.
Traits
- Build
Coding - Coding builder.
- Coding
- A bijection between values and codewords. Codewords are sequences of fragments. Each fragment occupies constant number of bits.
- Decoder
- Decoder that decodes a value for codeword given fragment by fragment.
- Serializable
Coding - Codings that implement
SerializableCodingcan be serialized/deserialized.