Compressed static maps based on solving linear systems.
Modules
Structs
- Compressed static function (immutable map) that maps hashable keys to values of any type.
- Pre-fills the value vector of
ls::Mapwith random values. - Pre-fills each 64-bit fragment of the value vector of
ls::Mapwith given pattern. - Static function (immutable map) that maps hashable keys to unsigned integer values of given bit-size.
- Configuration accepted by
ls::Mapconstructors.
Traits
- Trait for pre-filling vector of values in
ls::Map.